@@ -19,7 +19,7 @@ use std::path::{Path, PathBuf};
 use std::str;
 
 #[derive(Debug)]
-pub struct Project {
+pub(crate) struct Project {
     pub dir: Directory,
     source_dir: Directory,
     pub target_dir: Directory,
@@ -35,7 +35,7 @@ pub struct Project {
 }
 
 #[derive(Debug)]
-pub struct PathDependency {
+pub(crate) struct PathDependency {
     pub name: String,
     pub normalized_path: Directory,
 }
@@ -46,7 +46,7 @@ struct Report {
 }
 
 impl Runner {
-    pub fn run(&mut self) {
+    pub(crate) fn run(&mut self) {
         let mut tests = expand_globs(&self.tests);
         filter(&mut tests);
 
@@ -181,10 +181,10 @@ impl Runner {
     }
 
     fn write(&self, project: &mut Project) -> Result<()> {
-        let manifest_toml = basic_toml::to_string(&project.manifest)?;
+        let manifest_toml = toml::to_string(&project.manifest)?;
 
         let config = self.make_config();
-        let config_toml = basic_toml::to_string(&config)?;
+        let config_toml = toml::to_string(&config)?;
 
         fs::create_dir_all(path!(project.dir / ".cargo"))?;
         fs::write(path!(project.dir / ".cargo" / "config.toml"), config_toml)?;
